summaryrefslogtreecommitdiff
path: root/novaclient/i18n.py
diff options
context:
space:
mode:
authorAndrey Kurilin <akurilin@mirantis.com>2015-01-26 16:37:53 +0200
committerAndrey Kurilin <akurilin@mirantis.com>2015-04-20 13:52:38 +0300
commitccff3d3c948c1b0b3ce28f6928e39915b16d80ee (patch)
treed961d5d7814ea87ccd9cc02a342ac821ecc5e4eb /novaclient/i18n.py
parent97993537812c5979781a36b50d2adf8db57f7424 (diff)
downloadpython-novaclient-ccff3d3c948c1b0b3ce28f6928e39915b16d80ee.tar.gz
Remove all imports from oslo namespace
oslo namespace is deprecated Change-Id: I345eb210222d8e973b99f27821099f52883ab27d
Diffstat (limited to 'novaclient/i18n.py')
-rw-r--r--novaclient/i18n.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/novaclient/i18n.py b/novaclient/i18n.py
index e9d39d4a..6a17312d 100644
--- a/novaclient/i18n.py
+++ b/novaclient/i18n.py
@@ -10,16 +10,16 @@
# License for the specific language governing permissions and limitations
# under the License.
"""oslo.i18n integration module for novaclient.
See http://docs.openstack.org/developer/oslo.i18n/usage.html .
"""
-from oslo import i18n
+import oslo_i18n
-_translators = i18n.TranslatorFactory(domain='novaclient')
+_translators = oslo_i18n.TranslatorFactory(domain='novaclient')
# The primary translation function using the well-known name "_"
_ = _translators.primary
@@ -10,16 +10,16 @@
# License for the specific language governing permissions and limitations
# under the License.
-"""oslo.i18n integration module for novaclient.
+"""oslo_i18n integration module for novaclient.
See http://docs.openstack.org/developer/oslo.i18n/usage.html .
"""